﻿

function Get-AzureAccessTokenMSI
{
    # Get an access token for the MSI
    $response = Invoke-WebRequest -Uri 'http://169.254.169.254/metadata/identity/oauth2/token?api-version=2018-02-01&resource=https%3A%2F%2Fmanagement.azure.com%2F' -Headers @{Metadata="true"}
    $content =$response.Content | ConvertFrom-Json
    $access_token = $content.access_token
    
    return $access_token
}

function Get-AzureApplicationGateway
{
    $access_token = Get-AzureAccessTokenMSI
    $subscriptionId = Get-AzureSubscriptionIdForVM -access_token $access_token
    $resourceGroupName = Get-AzureResourceGroupNameForVM -access_token $access_token -subscriptionId $subscriptionId
    $applicationGatewayName = Get-AzureApplicationGatewayNameForVM -access_token $access_token -subscriptionId $subscriptionId -resourceGroupName $resourceGroupName

    $apInfoRest = (Invoke-WebRequest -Uri https://management.azure.com/subscriptions/$subscriptionId/resourceGroups/$resourceGroupName/providers/Microsoft.Network/applicationGateways/"$applicationGatewayName"?api-version=2018-02-01 -Method GET -ContentType "application/json" -Headers @{ Authorization ="Bearer $access_token"}).content
    $apInfoJson = $apInfoRest | ConvertFrom-Json
    return $apInfoJson
}

function Set-AzureApplicationGateway([PSCustomObject] $apInfoJson)
{
    $access_token = Get-AzureAccessTokenMSI
    $subscriptionId = Get-AzureSubscriptionIdForVM -access_token $access_token
    $resourceGroupName = Get-AzureResourceGroupNameForVM -access_token $access_token -subscriptionId $subscriptionId
    $applicationGatewayName = Get-AzureApplicationGatewayNameForVM -access_token $access_token -subscriptionId $subscriptionId -resourceGroupName $resourceGroupName

    $apInfoRest = $apInfoJson | ConvertTo-Json -Depth 99
    $response = (Invoke-WebRequest -Uri https://management.azure.com/subscriptions/$subscriptionId/resourceGroups/$resourceGroupName/providers/Microsoft.Network/applicationGateways/"$applicationGatewayName"?api-version=2018-02-01 -Method PUT -ContentType "application/json" -Headers @{ Authorization ="Bearer $access_token"} -Body $apInfoRest ).content
    return $response 
}

function Set-AzureApplicationGatewayToDrain
{
    $apInfoJson = Get-AzureApplicationGateway
    $apInfoJson.properties.backendHttpSettingsCollection.Item(0).properties.connectionDraining.enabled = 'True'
    $apInfoJson.properties.backendHttpSettingsCollection.Item(0).properties.connectionDraining.drainTimeoutInSec = 3600
    $apInfoJson.properties.backendHttpSettingsCollection.Item(1).properties.connectionDraining.enabled = 'True'
    $apInfoJson.properties.backendHttpSettingsCollection.Item(1).properties.connectionDraining.drainTimeoutInSec = 3600
    $response = Set-AzureApplicationGateway -apInfoJson $apInfoJson
}

function Set-AzureApplicationGatewayToUnDrain
{
    $apInfoJson = Get-AzureApplicationGateway
    $apInfoJson.properties.backendHttpSettingsCollection.Item(0).properties.connectionDraining.enabled = 'False'
    $apInfoJson.properties.backendHttpSettingsCollection.Item(0).properties.connectionDraining.drainTimeoutInSec = 3600
    $apInfoJson.properties.backendHttpSettingsCollection.Item(1).properties.connectionDraining.enabled = 'False'
    $apInfoJson.properties.backendHttpSettingsCollection.Item(1).properties.connectionDraining.drainTimeoutInSec = 3600
    $response = Set-AzureApplicationGateway -apInfoJson $apInfoJson
}

function removeVMfromApplicationGatewayBackendPool([string] $vmIP)
{
    $apInfoJson = Get-AzureApplicationGateway
    $BackendIpAddress = [System.Collections.ArrayList] $apInfoJson.properties.backendAddressPools.properties.backendAddresses
    $BackendIpAddress = $BackendIpAddress | Where-Object{$_.ipAddress -ne $vmIP }
    $apInfoJson.properties.backendAddressPools.properties.backendAddresses = [System.Object[]] $BackendIpAddress
    $response = Set-AzureApplicationGateway -apInfoJson $apInfoJson
}

function addVMfromApplicationGatewayBackendPool([string] $vmIP)
{
    $apInfoJson = Get-AzureApplicationGateway
    $BackendIpAddress = [System.Collections.ArrayList] $apInfoJson.properties.backendAddressPools.properties.backendAddresses
    $newBackendIpAddress = $BackendIpAddress | Where-Object{$_.ipAddress -eq $vmIP }    

    if($newBackendIpAddress.Count -eq 0)
    {
        $MyIpAddress = New-Object PSObject
        Add-Member -InputObject $MyIpAddress -MemberType NoteProperty -Name ipAddress -Value $vmIP
        $BackendIpAddress.Add($MyIpAddress)    
    }
    $apInfoJson.properties.backendAddressPools.properties.backendAddresses = [System.Object[]] $BackendIpAddress
    $response = Set-AzureApplicationGateway -apInfoJson $apInfoJson
}


function drainAosVM
{
    Set-AzureApplicationGatewayToDrain  
    $MyIpAddress = getMyVMIP
    removeVMfromApplicationGatewayBackendPool -vmIP $MyIpAddress
}

function unDrainAosVM
{
    Set-AzureApplicationGatewayToUnDrain
    $MyIpAddress = getMyVMIP
    addVMfromApplicationGatewayBackendPool -vmIP $MyIpAddress
}

function getMyVMIP ()
{
    $ip=get-WmiObject Win32_NetworkAdapterConfiguration|Where {$_.Ipaddress.length -gt 1} 

    return $ip.ipaddress[0] 
}

function Get-AzureSubscriptionIdForVM ([string]  $access_token )
{
    $subscriptionInfoRest = (Invoke-WebRequest -Uri https://management.azure.com/subscriptions?api-version=2018-02-01 -Method GET -ContentType "application/json" -Headers @{ Authorization ="Bearer $access_token"}).content
    $subscriptionInfo = $subscriptionInfoRest | ConvertFrom-Json
    return $subscriptionInfo.value.subscriptionId

}

function Get-AzureResourceGroupNameForVM ([string]  $access_token, [string] $subscriptionId )
{
    $resourceGroupInfoRest = (Invoke-WebRequest -Uri https://management.azure.com/subscriptions/$subscriptionId/resourcegroups?api-version=2018-02-01 -Method GET -ContentType "application/json" -Headers @{ Authorization ="Bearer $access_token"}).content
    $resourceGroupInfo = $resourceGroupInfoRest | ConvertFrom-Json
    return $resourceGroupInfo.value.Name
}

function Get-AzureApplicationGatewayNameForVM ([string]  $access_token, [string] $subscriptionId, [string] $resourceGroupName  )
{
    $applicationGatewayInfoRest = (Invoke-WebRequest -Uri https://management.azure.com/subscriptions/$subscriptionId/resourcegroups/$resourceGroupName/providers/Microsoft.Network/applicationGateways?api-version=2018-02-01 -Method GET -ContentType "application/json" -Headers @{ Authorization ="Bearer $access_token"}).content
    $applicationGatewayInfo = $applicationGatewayInfoRest | ConvertFrom-Json
    return $applicationGatewayInfo.value.Name
}


Export-ModuleMember -Function drainAosVM
Export-ModuleMember -Function unDrainAosVM


# SIG # Begin signature block
# MIIkhAYJKoZIhvcNAQcCoIIkdTCCJHECAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDsUZB6MYDQKFkX
# t3TJ/qFOPtdo5cBdW73oE9lEBpGom6CCDYUwggYDMIID66ADAgECAhMzAAABUptA
# n1BWmXWIAAAAAAFSMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMTkwNTAyMjEzNzQ2WhcNMjAwNTAyMjEzNzQ2WjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQCxp4nT9qfu9O10iJyewYXHlN+WEh79Noor9nhM6enUNbCbhX9vS+8c/3eIVazS
# YnVBTqLzW7xWN1bCcItDbsEzKEE2BswSun7J9xCaLwcGHKFr+qWUlz7hh9RcmjYS
# kOGNybOfrgj3sm0DStoK8ljwEyUVeRfMHx9E/7Ca/OEq2cXBT3L0fVnlEkfal310
# EFCLDo2BrE35NGRjG+/nnZiqKqEh5lWNk33JV8/I0fIcUKrLEmUGrv0CgC7w2cjm
# bBhBIJ+0KzSnSWingXol/3iUdBBy4QQNH767kYGunJeY08RjHMIgjJCdAoEM+2mX
# v1phaV7j+M3dNzZ/cdsz3oDfAgMBAAGjggGCMIIBfjAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQU3f8Aw1sW72WcJ2bo/QSYGzVrRYcw
# VAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJh
# dGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNMjMwMDEyKzQ1NDEzNjAfBgNVHSMEGDAW
# gBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIw
# MTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDEx
# XzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggIB
# AJTwROaHvogXgixWjyjvLfiRgqI2QK8GoG23eqAgNjX7V/WdUWBbs0aIC3k49cd0
# zdq+JJImixcX6UOTpz2LZPFSh23l0/Mo35wG7JXUxgO0U+5drbQht5xoMl1n7/TQ
# 4iKcmAYSAPxTq5lFnoV2+fAeljVA7O43szjs7LR09D0wFHwzZco/iE8Hlakl23ZT
# 7FnB5AfU2hwfv87y3q3a5qFiugSykILpK0/vqnlEVB0KAdQVzYULQ/U4eFEjnis3
# Js9UrAvtIhIs26445Rj3UP6U4GgOjgQonlRA+mDlsh78wFSGbASIvK+fkONUhvj8
# B8ZHNn4TFfnct+a0ZueY4f6aRPxr8beNSUKn7QW/FQmn422bE7KfnqWncsH7vbNh
# G929prVHPsaa7J22i9wyHj7m0oATXJ+YjfyoEAtd5/NyIYaE4Uu0j1EhuYUo5VaJ
# JnMaTER0qX8+/YZRWrFN/heps41XNVjiAawpbAa0fUa3R9RNBjPiBnM0gvNPorM4
# dsV2VJ8GluIQOrJlOvuCrOYDGirGnadOmQ21wPBoGFCWpK56PxzliKsy5NNmAXcE
# x7Qb9vUjY1WlYtrdwOXTpxN4slzIht69BaZlLIjLVWwqIfuNrhHKNDM9K+v7vgrI
# bf7l5/665g0gjQCDCN6Q5sxuttTAEKtJeS/pkpI+DbZ/MIIHejCCBWKgAwIBAgIK
# YQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEw
# OTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
# VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+la
# UKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc
# 6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4D
# dato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+
# lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
# kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6
# A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmd
# X4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL
# 5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zd
# sGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3
# T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS
# 4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRI
# bmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
# BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBD
# uRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jv
# c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEF
# BQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1h
# cnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkA
# YwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn
# 8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7
# v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0b
# pdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/
# KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvy
# CInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
# mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJi
# hsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYb
# BL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbS
# oqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sL
# gOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtX
# cVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGCFlUwghZRAgEBMIGVMH4x
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01p
# Y3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMAAAFSm0CfUFaZdYgAAAAA
# AVIwDQYJYIZIAWUDBAIBBQCggdYwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIESh
# KTevUNywO9kCFjqbtNkq7f6rvKF7dwauZWoCQ23jMGoGCisGAQQBgjcCAQwxXDBa
# oDyAOgBBAHUAdABvAEQAZQBwAGwAbwB5AFIAZQBwAG8AcgB0AEEAbgBkAFMAeQBu
# AGMARABCAC4AcABzADGhGoAYaHR0cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqG
# SIb3DQEBAQUABIIBAGF18xZQUOyEP9j7heQ+W+etXxWHmGM2J1Yo+83/uZ62dpGv
# Ni8lkS/ZedopQsN9TKyOAfjVa8shz85asp74XGop/9fKn3UZ/l6MzWfKcgPKnCwN
# 1cYyQI2G1jTUmv2UflhHLG+lscYwSACGFSPRexqWwrhSWCLylosuACeIMmvr741D
# 8V5BbCKSVNUI9e2O957ky/ALnUpn0wHzfrjUsgMXBhavRRYkd/rtq6SA1eDXlcUi
# opxJz4bnM4tIwnO+PgO98yadzHUuyKbrBFi9ZKLQkD1jQvfhYi9SCgm5jzC4qW8P
# tqvhnc0A/+5pXBuenBnlQne3JCp8drQ/c4gKEmGhghO3MIITswYKKwYBBAGCNwMD
# ATGCE6MwghOfBgkqhkiG9w0BBwKgghOQMIITjAIBAzEPMA0GCWCGSAFlAwQCAQUA
# MIIBWAYLKoZIhvcNAQkQAQSgggFHBIIBQzCCAT8CAQEGCisGAQQBhFkKAwEwMTAN
# BglghkgBZQMEAgEFAAQgLqut9QexwfgkYixM2auSEDOI5RFvEqNiQWSBvHNhEm4C
# Bl5MCgKZoxgTMjAyMDAzMjQwNjUwMTAuNTU2WjAHAgEBgAIB9KCB1KSB0TCBzjEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWlj
# cm9zb2Z0IE9wZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAkBgNVBAsTHVRoYWxlcyBU
# U1MgRVNOOkMwRjQtMzA4Ni1ERUY4MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1T
# dGFtcCBTZXJ2aWNloIIPHzCCBPUwggPdoAMCAQICEzMAAAEBgT4iRv36OOIAAAAA
# AQEwDQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
# HhcNMTkwOTA2MjA0MTE1WhcNMjAxMjA0MjA0MTE1WjCBzjELMAkGA1UEBhMCVVMx
# EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
# FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWljcm9zb2Z0IE9wZXJh
# dGlvbnMgUHVlcnRvIFJpY28xJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkMwRjQt
# MzA4Ni1ERUY4MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNl
# MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAslD2WMiE5DW9qiKtT90o
# XXvgiZR3Xb3Isb54eAGSkdfywiXWjqlsgbbHmENeEuqPdfln10s5mRcveJeu5uyG
# YVCwDwC9ftQ7D3w2ubzxtpw1CkzGiOJ35fzuYaTtRitCZbnTj0ofrtpTr3f7mPOR
# a6YmL4IZh3w5LexlAvsRPYwzkU5d3PsUC9trlJrtNVj+bnkbBknsWoBcCfJAC0iG
# rzfHkkqXQI9oF2Pi9bod7HQbCfqX+K6m3zNVbiGTuz3ALdMkIH7/j+jMwMn2/DCA
# uBCMh/0p7btiZAbMIMkwlvkUaFht6uM2QIHrPAVO62hydZo75i9cXQf2i3mOlcSv
# WQIDAQABo4IBGzCCARcwHQYDVR0OBBYEFL++mJrvTfwOjJhgkS2MFSQduaSRMB8G
# A1UdIwQYMBaAFNVjOlyKMZDzQ3t8RhvFM2hahW1VMFYGA1UdHwRPME0wS6BJoEeG
# RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Rp
# bVN0YVBDQV8yMDEwLTA3LTAxLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUH
# MAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljVGltU3Rh
# UENBXzIwMTAtMDctMDEuY3J0MAwGA1UdEwEB/wQCMAAwEwYDVR0lBAwwCgYIKwYB
# BQUHAwgwDQYJKoZIhvcNAQELBQADggEBAB89tlren+VXtliQT9FZ9arqBKMgnv+M
# VODASkFR5/JMc+dAbcEXb2urSOiQ6qJ5SoNGLBheDpaaebHDJ+ZWxIIBF0ld9sdY
# LfA4nDQfQp9QsiapnQPEFigODxNctVWA39CCXyCljOfSf/ZA2/ucRVZeWkg255nS
# qEZ/saG2GnLjSH30sULyaYr875x4oNEdhkhh403yNpCSVEEtapEt3aaYNK9HF83h
# UdwV79OHHzcrO9a9SNo6TfMZ/nQ6ZCnK6NTgQog7LU8qYhsoassS9n8S+nEtsGGw
# dFLi1wLfs+Hbe2Hg77AQr9uDnmA0e/RT0iPBCMvHzOy7oUVSVN9rfWAwggZxMIIE
# WaADAgECAgphCYEqAAAAAAACMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9v
# dCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0xMDA3MDEyMTM2NTVaFw0y
# NTA3MDEyMTQ2NTVaMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqR0NvHcRijog7PwTl/X6f2mUa3RU
# ENWlCgCChfvtfGhLLF/Fw+Vhwna3PmYrW/AVUycEMR9BGxqVHc4JE458YTBZsTBE
# D/FgiIRUQwzXTbg4CLNC3ZOs1nMwVyaCo0UN0Or1R4HNvyRgMlhgRvJYR4YyhB50
# YWeRX4FUsc+TTJLBxKZd0WETbijGGvmGgLvfYfxGwScdJGcSchohiq9LZIlQYrFd
# /XcfPfBXday9ikJNQFHRD5wGPmd/9WbAA5ZEfu/QS/1u5ZrKsajyeioKMfDaTgaR
# togINeh4HLDpmc085y9Euqf03GS9pAHBIAmTeM38vMDJRF1eFpwBBU8iTQIDAQAB
# o4IB5jCCAeIwEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0OBBYEFNVjOlyKMZDzQ3t8
# RhvFM2hahW1VMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIB
# hjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fO
# mhjEMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9w
# a2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNybDBaBggr
# BgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
# bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MIGgBgNVHSAB
# Af8EgZUwgZIwgY8GCSsGAQQBgjcuAzCBgTA9BggrBgEFBQcCARYxaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL1BLSS9kb2NzL0NQUy9kZWZhdWx0Lmh0bTBABggrBgEF
# BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBQAG8AbABpAGMAeQBfAFMAdABhAHQAZQBt
# AGUAbgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAB+aIUQ3ixuCYP4FxAz2do6Eh
# b7Prpsz1Mb7PBeKp/vpXbRkws8LFZslq3/Xn8Hi9x6ieJeP5vO1rVFcIK1GCRBL7
# uVOMzPRgEop2zEBAQZvcXBf/XPleFzWYJFZLdO9CEMivv3/Gf/I3fVo/HPKZeUqR
# UgCvOA8X9S95gWXZqbVr5MfO9sp6AG9LMEQkIjzP7QOllo9ZKby2/QThcJ8ySif9
# Va8v/rbljjO7Yl+a21dA6fHOmWaQjP9qYn/dxUoLkSbiOewZSnFjnXshbcOco6I8
# +n99lmqQeKZt0uGc+R38ONiU9MalCpaGpL2eGq4EQoO4tYCbIjggtSXlZOz39L9+
# Y1klD3ouOVd2onGqBooPiRa6YacRy5rYDkeagMXQzafQ732D8OE7cQnfXXSYIghh
# 2rBQHm+98eEA3+cxB6STOvdlR3jo+KhIq/fecn5ha293qYHLpwmsObvsxsvYgrRy
# zR30uIUBHoD7G4kqVDmyW9rIDVWZeodzOwjmmC3qjeAzLhIp9cAvVCch98isTtoo
# uLGp25ayp0Kiyc8ZQU3ghvkqmqMRZjDTu3QyS99je/WZii8bxyGvWbWu3EQ8l1Bx
# 16HSxVXjad5XwdHeMMD9zOZN+w2/XU/pnR4ZOC+8z1gFLu8NoFA12u8JJxzVs341
# Hgi62jbb01+P3nSISRKhggOtMIIClQIBATCB/qGB1KSB0TCBzjELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEpMCcGA1UECxMgTWljcm9zb2Z0IE9w
# ZXJhdGlvbnMgUHVlcnRvIFJpY28xJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkMw
# RjQtMzA4Ni1ERUY4MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2
# aWNloiUKAQEwCQYFKw4DAhoFAAMVAAglU0DiIIH6Ddu2/lV83eEn3wXxoIHeMIHb
# pIHYMIHVMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSkwJwYD
# VQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVydG8gUmljbzEnMCUGA1UECxMe
# bkNpcGhlciBOVFMgRVNOOjRERTktMEM1RS0zRTA5MSswKQYDVQQDEyJNaWNyb3Nv
# ZnQgVGltZSBTb3VyY2UgTWFzdGVyIENsb2NrMA0GCSqGSIb3DQEBBQUAAgUA4iOf
# gzAiGA8yMDIwMDMyNDA0NTAxMVoYDzIwMjAwMzI1MDQ1MDExWjB0MDoGCisGAQQB
# hFkKBAExLDAqMAoCBQDiI5+DAgEAMAcCAQACAgV0MAcCAQACAhr/MAoCBQDiJPED
# AgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwGgCjAIAgEAAgMW42Ch
# CjAIAgEAAgMHoSAwDQYJKoZIhvcNAQEFBQADggEBAFQorpAlMuGBdb5zJ5OK8bDs
# 3wA2dmFwxE7omuaqGJmiO849i/pSpdrU0bPDwO3pdxJEPj2r4Pqukzu2CBcM1LJ0
# HQepAFwtJzA8k8KIceTGI/2Z6LF/ImvZcgSrW84E3zmxoRxoG5DuXrrRjNacWsEM
# u5sA1lYF65JMZqgmdXPNshGzeudiWmZMHTu3i2I4ioXk7GLhXLK1xncnUlWusAbV
# ygkPrNPSGKk2pHxQmJ7nQsWpix98iwjZuMXCBLm+wBtmcldY1Iz6ZONHSMDiPC9h
# SmuqO5WTgpjLswNrtWJqKbsQ6Od0C3k4PpEmq4GnhEHPZ4TojndIggoqI8g2pRox
# ggL1MIIC8QIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
# bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
# aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAA
# AQGBPiJG/fo44gAAAAABATANBglghkgBZQMEAgEFAKCCATIwGgYJKoZIhvcNAQkD
# MQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCB2neoeuscf57MfGOUF42BZ
# 9hG0lbs1+vzBMeWcQSauSDCB4gYLKoZIhvcNAQkQAgwxgdIwgc8wgcwwgbEEFAgl
# U0DiIIH6Ddu2/lV83eEn3wXxMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
# UENBIDIwMTACEzMAAAEBgT4iRv36OOIAAAAAAQEwFgQUdrubEGkYKHg9FAU1gqbi
# zT2JU7QwDQYJKoZIhvcNAQELBQAEggEADzzYY9r16UaS9IXJ4Jg4XKzC3o5Athtw
# rCpJgaPaK3E3mCx0xsJZhLciQndK9oeDgBWE8FWszLTv7/vArVx3cxCUjypEiIrj
# nF+FjdH1Ls72J33c61EI2mezJkRY0m3UDxaqrRRVsrUY9iSHz4dfoHYV44tl3cSg
# mj6coHJwF5anaB9asQFlig1vEpRg/M8z9eu2CN71miIaPusDQbhNQ3pExoCwTmXj
# 8lMYMm7N73x2YDDI2dEe3095nVN/xJ2SoLoEgb8hoDkfuydIOH3ku8bVQk8x1Iq4
# DXBdYhQdHmb3xEVwsIiJOROlQUuYd58MgJ3uaAVE3h7KWBdsrmocEw==
# SIG # End signature block
